@@ -967,9 +967,9 @@ END
          next;
       }
    }
-   ($stdout,$stderr)=$handle->cwd("../..");
+   ($stdout,$stderr)=$handle->cwd("~");
    ($stdout,$stderr)=$handle->cmd("catalyst.pl FullAutoAPI",'__display__');
-   #($stdout,$stderr)=$handle->cwd("FullAutoAPI");
+   ($stdout,$stderr)=$handle->cwd("FullAutoAPI");
    ($stdout,$stderr)=$handle->cmd("perl Makefile.PL",'__display__');
    my $pm_path="./lib/FullAutoAPI.pm";
    $ad="    Session%NL%".
